==> kubernetes-model-flowcontrol-5.12.2-sources.jar: io/fabric8/kubernetes/api/model/flowcontrol/v1beta1/ResourcePolicyRuleBuilder.java <==
package io.fabric8.kubernetes.api.model.flowcontrol.v1beta1;

import io.fabric8.kubernetes.api.builder.VisitableBuilder;
import java.lang.Object;
import java.lang.Boolean;
public class ResourcePolicyRuleBuilder extends io.fabric8.kubernetes.api.model.flowcontrol.v1beta1.ResourcePolicyRuleFluentImpl<io.fabric8.kubernetes.api.model.flowcontrol.v1beta1.ResourcePolicyRuleBuilder> implements io.fabric8.kubernetes.api.builder.VisitableBuilder<io.fabric8.kubernetes.api.model.flowcontrol.v1beta1.ResourcePolicyRule,io.fabric8.kubernetes.api.model.flowcontrol.v1beta1.ResourcePolicyRuleBuilder>{
  public ResourcePolicyRuleBuilder() {
    this(false);
  }
  public ResourcePolicyRuleBuilder(java.lang.Boolean validationEnabled) {
    this(new ResourcePolicyRule(), validationEnabled);
  }
  public ResourcePolicyRuleBuilder(io.fabric8.kubernetes.api.model.flowcontrol.v1beta1.ResourcePolicyRuleFluent<?> fluent) {
    this(fluent, false);
  }
  public ResourcePolicyRuleBuilder(io.fabric8.kubernetes.api.model.flowcontrol.v1beta1.ResourcePolicyRuleFluent<?> fluent,java.lang.Boolean validationEnabled) {
    this(fluent, new ResourcePolicyRule(), validationEnabled);
  }
  public ResourcePolicyRuleBuilder(io.fabric8.kubernetes.api.model.flowcontrol.v1beta1.ResourcePolicyRuleFluent<?> fluent,io.fabric8.kubernetes.api.model.flowcontrol.v1beta1.ResourcePolicyRule instance) {
    this(fluent, instance, false);
  }
  public ResourcePolicyRuleBuilder(io.fabric8.kubernetes.api.model.flowcontrol.v1beta1.ResourcePolicyRuleFluent<?> fluent,io.fabric8.kubernetes.api.model.flowcontrol.v1beta1.ResourcePolicyRule instance,java.lang.Boolean validationEnabled) {
    this.fluent = fluent; 
    fluent.withApiGroups(instance.getApiGroups()); 
    fluent.withClusterScope(instance.getClusterScope()); 
    fluent.withNamespaces(instance.getNamespaces()); 
    fluent.withResources(instance.getResources()); 
    fluent.withVerbs(instance.getVerbs()); 
    fluent.withAdditionalProperties(instance.getAdditionalProperties());

    this.validationEnabled = validationEnabled; 
  }
  public ResourcePolicyRuleBuilder(io.fabric8.kubernetes.api.model.flowcontrol.v1beta1.ResourcePolicyRule instance) {
    this(instance,false);
  }
  public ResourcePolicyRuleBuilder(io.fabric8.kubernetes.api.model.flowcontrol.v1beta1.ResourcePolicyRule instance,java.lang.Boolean validationEnabled) {
    this.fluent = this; 
    this.withApiGroups(instance.getApiGroups()); 
    this.withClusterScope(instance.getClusterScope()); 
    this.withNamespaces(instance.getNamespaces()); 
    this.withResources(instance.getResources()); 
    this.withVerbs(instance.getVerbs()); 
    this.withAdditionalProperties(instance.getAdditionalProperties());

    this.validationEnabled = validationEnabled; 
  }
  io.fabric8.kubernetes.api.model.flowcontrol.v1beta1.ResourcePolicyRuleFluent<?> fluent;
  java.lang.Boolean validationEnabled;
  public io.fabric8.kubernetes.api.model.flowcontrol.v1beta1.ResourcePolicyRule build() {
    ResourcePolicyRule buildable = new ResourcePolicyRule(fluent.getApiGroups(),fluent.getClusterScope(),fluent.getNamespaces(),fluent.getResources(),fluent.getVerbs());
    buildable.setAdditionalProperties(fluent.getAdditionalProperties());
    return buildable;
  }
  public boolean equals(java.lang.Object o) {
    if (this == o) return true;
    if (o == null || getClass() != o.getClass()) return false;
    if (!super.equals(o)) return false;
    ResourcePolicyRuleBuilder that = (ResourcePolicyRuleBuilder) o;
    if (fluent != null &&fluent != this ? !fluent.equals(that.fluent) :that.fluent != null &&fluent != this ) return false;

    if (validationEnabled != null ? !validationEnabled.equals(that.validationEnabled) :that.validationEnabled != null) return false;
    return true;
  }
  public int hashCode() {
    return java.util.Objects.hash(fluent,  validationEnabled,  super.hashCode());
  }
  
}

==> kubernetes-model-flowcontrol-6.3.0-sources.jar: io/fabric8/kubernetes/api/model/flowcontrol/v1beta1/ResourcePolicyRuleBuilder.java <==
package io.fabric8.kubernetes.api.model.flowcontrol.v1beta1;

import io.fabric8.kubernetes.api.builder.VisitableBuilder;
import java.lang.Boolean;
public class ResourcePolicyRuleBuilder extends ResourcePolicyRuleFluentImpl<ResourcePolicyRuleBuilder> implements VisitableBuilder<ResourcePolicyRule,ResourcePolicyRuleBuilder>{
  public ResourcePolicyRuleBuilder() {
    this(false);
  }
  public ResourcePolicyRuleBuilder(Boolean validationEnabled) {
    this(new ResourcePolicyRule(), validationEnabled);
  }
  public ResourcePolicyRuleBuilder(ResourcePolicyRuleFluent<?> fluent) {
    this(fluent, false);
  }
  public ResourcePolicyRuleBuilder(ResourcePolicyRuleFluent<?> fluent,Boolean validationEnabled) {
    this(fluent, new ResourcePolicyRule(), validationEnabled);
  }
  public ResourcePolicyRuleBuilder(ResourcePolicyRuleFluent<?> fluent,ResourcePolicyRule instance) {
    this(fluent, instance, false);
  }
  public ResourcePolicyRuleBuilder(ResourcePolicyRuleFluent<?> fluent,ResourcePolicyRule instance,Boolean validationEnabled) {
    this.fluent = fluent; 
    fluent.withApiGroups(instance.getApiGroups()); 
    fluent.withClusterScope(instance.getClusterScope()); 
    fluent.withNamespaces(instance.getNamespaces()); 
    fluent.withResources(instance.getResources()); 
    fluent.withVerbs(instance.getVerbs()); 
    fluent.withAdditionalProperties(instance.getAdditionalProperties());

    this.validationEnabled = validationEnabled; 
  }
  public ResourcePolicyRuleBuilder(ResourcePolicyRule instance) {
    this(instance,false);
  }
  public ResourcePolicyRuleBuilder(ResourcePolicyRule instance,Boolean validationEnabled) {
    this.fluent = this; 
    this.withApiGroups(instance.getApiGroups()); 
    this.withClusterScope(instance.getClusterScope()); 
    this.withNamespaces(instance.getNamespaces()); 
    this.withResources(instance.getResources()); 
    this.withVerbs(instance.getVerbs()); 
    this.withAdditionalProperties(instance.getAdditionalProperties());

    this.validationEnabled = validationEnabled; 
  }
  ResourcePolicyRuleFluent<?> fluent;
  Boolean validationEnabled;
  public ResourcePolicyRule build() {
    ResourcePolicyRule buildable = new ResourcePolicyRule(fluent.getApiGroups(),fluent.getClusterScope(),fluent.getNamespaces(),fluent.getResources(),fluent.getVerbs());
    buildable.setAdditionalProperties(fluent.getAdditionalProperties());
    return buildable;
  }
  
}
